function testKtemp
% testKtemp  Verify e = f(T) and T = g(e) routines for K type thermocouples
%
% Synopsis: testKtemp
%
% Input:  none
%
% Output:  Plot of errors in emf and temperature for round-trip
%          evaluation of calibration polynomials
%
% Author: Gerald Recktenwald, gerry@me.pdx.edu
%         Mechanical and Materials Engineering, Portland State University
%         Portland, Oregon, 2006-04-03

%  Use two round-trip tests.  e -> T -> e2, and T -> e -> T2

% --- Specify e, compute T, then reverse to get e2
e = linspace(-5.89,20.64,1000)*1e-3;    %  range of emf values
T = Ktemp(e);
e2 = emfKtype(T);
fprintf('norm(e-e2,inf) = %g\n',norm(e-e2,inf));
plot(e,e-e2,'.');
xlabel('e  (V)');   ylabel('Error:  e-e2  (V)');


% --- Check in reverse:
%     Specify T, compute e, then reverse to get T2
T = linspace(-199.9,1370,1000);    %  range of T values
e = emfKtype(T);
T2 = Ktemp(e);
fprintf('norm(T-T2,inf) = %g\n',norm(T-T2,inf));
figure
plot(T,T-T2,'.');
xlabel('T  (C)');   ylabel('Error:  T-T2  (C)');
